@@ -165,19 +165,34 @@ class BaseField(IBaseConfig):
             time_stamp,
         ).lower()
 
-    def set_display_detail(self, display_detail):
+    def set_display_detail(self, display_detail: bool):
+        self.check_field_value_type(
+            field_key=self.DISPLAY_DETAIL,
+            field_value=display_detail,
+            field_type=str,
+        )
         self.result[self.DISPLAY_DETAIL] = display_detail
 
     def get_display_detail(self):
         return self.result.get(self.DISPLAY_DETAIL)
 
-    def set_display_in_form_add(self, display_in_form_add):
+    def set_display_in_form_add(self, display_in_form_add: bool):
+        self.check_field_value_type(
+            field_key=self.DISPLAY_IN_FORM_ADD,
+            field_value=display_in_form_add,
+            field_type=bool,
+        )
         self.result[self.DISPLAY_IN_FORM_ADD] = display_in_form_add
 
     def get_display_in_form_add(self):
         return self.result.get(self.DISPLAY_IN_FORM_ADD)
 
-    def set_display_in_form_add_selected(self, display_in_form_add_selected):
+    def set_display_in_form_add_selected(self, display_in_form_add_selected: bool):
+        self.check_field_value_type(
+            field_key=self.DISPLAY_IN_FORM_ADD_SELECTED,
+            field_value=display_in_form_add_selected,
+            field_type=bool,
+        )
         self.result[self.DISPLAY_IN_FORM_ADD_SELECTED] = display_in_form_add_selected
 
     def get_display_in_form_add_selected(self):
@@ -189,19 +204,34 @@ class BaseField(IBaseConfig):
     def get_order_form_add(self):
         return self.result.get(self.ORDER_FORM_ADD)
 
-    def set_required_form_add(self, required_form_add):
+    def set_required_form_add(self, required_form_add: bool):
+        self.check_field_value_type(
+            field_key=self.REQUIRED_FORM_ADD,
+            field_value=required_form_add,
+            field_type=bool,
+        )
         self.result[self.REQUIRED_FORM_ADD] = required_form_add
 
     def get_required_form_add(self):
         return self.result.get(self.REQUIRED_FORM_ADD)
 
-    def set_display_in_form_update(self, display_in_form_update):
+    def set_display_in_form_update(self, display_in_form_update: bool):
+        self.check_field_value_type(
+            field_key=self.DISPLAY_IN_FORM_UPDATE,
+            field_value=display_in_form_update,
+            field_type=bool,
+        )
         self.result[self.DISPLAY_IN_FORM_UPDATE] = display_in_form_update
 
     def get_display_in_form_update(self):
         return self.result.get(self.DISPLAY_IN_FORM_UPDATE)
 
-    def set_display_in_form_update_selected(self, display_in_form_update_selected):
+    def set_display_in_form_update_selected(self, display_in_form_update_selected: bool):
+        self.check_field_value_type(
+            field_key=self.DISPLAY_IN_FORM_UPDATE_SELECTED,
+            field_value=display_in_form_update_selected,
+            field_type=bool,
+        )
         self.result[
             self.DISPLAY_IN_FORM_UPDATE_SELECTED
         ] = display_in_form_update_selected
@@ -215,25 +245,45 @@ class BaseField(IBaseConfig):
     def get_order_form_update(self):
         return self.result.get(self.ORDER_FORM_UPDATE)
 
-    def set_required_form_update(self, required_form_update):
+    def set_required_form_update(self, required_form_update: bool):
+        self.check_field_value_type(
+            field_key=self.REQUIRED_FORM_UPDATE,
+            field_value=required_form_update,
+            field_type=bool,
+        )
         self.result[self.REQUIRED_FORM_UPDATE] = required_form_update
 
     def get_required_form_update(self):
         return self.result.get(self.REQUIRED_FORM_UPDATE)
 
-    def set_display_in_import_file(self, display_in_import_file):
+    def set_display_in_import_file(self, display_in_import_file: bool):
+        self.check_field_value_type(
+            field_key=self.DISPLAY_IN_IMPORT_FILE,
+            field_value=display_in_import_file,
+            field_type=bool,
+        )
         self.result[self.DISPLAY_IN_IMPORT_FILE] = display_in_import_file
 
     def get_display_in_import_file(self):
         return self.result.get(self.DISPLAY_IN_IMPORT_FILE)
 
-    def set_display_in_list_field(self, display_in_list_field):
+    def set_display_in_list_field(self, display_in_list_field: bool):
+        self.check_field_value_type(
+            field_key=self.DISPLAY_IN_LIST_FIELD,
+            field_value=display_in_list_field,
+            field_type=bool,
+        )
         self.result[self.DISPLAY_IN_LIST_FIELD] = display_in_list_field
 
     def get_display_in_list_field(self):
         return self.result.get(self.DISPLAY_IN_LIST_FIELD)
 
-    def set_display_in_list_field_selected(self, display_in_list_field_selected):
+    def set_display_in_list_field_selected(self, display_in_list_field_selected: bool):
+        self.check_field_value_type(
+            field_key=self.DISPLAY_IN_LIST_FIELD_SELECTED,
+            field_value=display_in_list_field_selected,
+            field_type=bool,
+        )
         self.result[
             self.DISPLAY_IN_LIST_FIELD_SELECTED
         ] = display_in_list_field_selected
@@ -247,31 +297,56 @@ class BaseField(IBaseConfig):
     def get_order_list_field(self):
         return self.result.get(self.ORDER_LIST_FIELD)
 
-    def set_display_in_filter(self, display_in_filter):
+    def set_display_in_filter(self, display_in_filter: bool):
+        self.check_field_value_type(
+            field_key=self.DISPLAY_IN_FILTER,
+            field_value=display_in_filter,
+            field_type=bool,
+        )
         self.result[self.DISPLAY_IN_FILTER] = display_in_filter
 
     def get_display_in_filter(self):
         return self.result.get(self.DISPLAY_IN_FILTER)
 
-    def set_disable_remove_form_input(self, disable_remove_form_input):
+    def set_disable_remove_form_input(self, disable_remove_form_input: bool):
+        self.check_field_value_type(
+            field_key=self.DISABLE_REMOVE_FORM_INPUT,
+            field_value=disable_remove_form_input,
+            field_type=bool,
+        )
         self.result[self.DISABLE_REMOVE_FORM_INPUT] = disable_remove_form_input
 
     def get_disable_remove_form_input(self):
         return self.result.get(self.DISABLE_REMOVE_FORM_INPUT)
 
-    def set_disable_remove_list(self, disable_remove_list):
+    def set_disable_remove_list(self, disable_remove_list: bool):
+        self.check_field_value_type(
+            field_key=self.DISABLE_REMOVE_LIST,
+            field_value=disable_remove_list,
+            field_type=bool,
+        )
         self.result[self.DISABLE_REMOVE_LIST] = disable_remove_list
 
     def get_disable_remove_list(self):
         return self.result.get(self.DISABLE_REMOVE_LIST)
 
-    def set_disable_required_form_input(self, disable_required_form_input):
+    def set_disable_required_form_input(self, disable_required_form_input: bool):
+        self.check_field_value_type(
+            field_key=self.DISABLE_REQUIRED_FORM_INPUT,
+            field_value=disable_required_form_input,
+            field_type=bool,
+        )
         self.result[self.DISABLE_REQUIRED_FORM_INPUT] = disable_required_form_input
 
     def get_disable_required_form_input(self):
         return self.result.get(self.DISABLE_REQUIRED_FORM_INPUT)
 
-    def set_enable_data_color(self, enable_data_color):
+    def set_enable_data_color(self, enable_data_color: bool):
+        self.check_field_value_type(
+            field_key=self.ENABLE_DATA_COLOR,
+            field_value=enable_data_color,
+            field_type=bool,
+        )
         self.result[self.ENABLE_DATA_COLOR] = enable_data_color
 
     def get_enable_data_color(self):
@@ -296,7 +371,11 @@ class BaseField(IBaseConfig):
 
     def set_field_key(self, field_key: str):
         if not field_key.startswith(MerchantConfigCommon.PREFIX_DYNAMIC_FIELD):
-            raise Exception("{}: {} is not valid".format(self.FIELD_KEY, field_key))
+            self.check_field_value_type(
+                field_key=self.FIELD_KEY,
+                field_value=field_key,
+                field_type=str,
+            )
         self.result[self.FIELD_KEY] = field_key
 
     def get_field_key(self):
@@ -377,6 +456,11 @@ class BaseField(IBaseConfig):
         return self.result.get(self.TRANSLATE_KEY)
 
     def set_support_sort(self, support_sort: bool):
+        self.check_field_value_type(
+            field_key=self.SUPPORT_SORT,
+            field_value=support_sort,
+            field_type=bool,
+        )
         self.result[self.SUPPORT_SORT] = support_sort
 
     def get_support_sort(self):
@@ -428,12 +512,22 @@ class BaseField(IBaseConfig):
         return self.result.get(self.LAST_UPDATE_BY)
 
     def set_is_encrypt(self, is_encrypt: bool):
+        self.check_field_value_type(
+            field_key=self.IS_ENCRYPT,
+            field_value=is_encrypt,
+            field_type=bool,
+        )
         self.result[self.IS_ENCRYPT] = is_encrypt
 
     def get_is_encrypt(self):
         return self.result.get(self.IS_ENCRYPT)
 
     def set_field_order(self, order: int):
+        self.check_field_value_type(
+            field_key=self.FIELD_ORDER,
+            field_value=order,
+            field_type=int,
+        )
         self.result[self.FIELD_ORDER] = order
 
     def get_field_order(self):
