@@ -23,3 +23,12 @@ class IBaseConfig:
         for key in self.get_all_attribute():
             if key in kwargs:
                 self.result[key] = kwargs.get(key)
+
+    @staticmethod
+    def check_field_value_type(field_key, field_value, field_type):
+        if type(field_value) != field_type:
+            raise Exception(
+                "{}: {} is not valid".format(
+                    field_key,field_value,
+                )
+            )
