@@ -1,9 +1,9 @@
 import os
 from elasticsearch import Elasticsearch
-# from mobio.libs.Singleton import Singleton
+from mobio.libs.Singleton import Singleton
 
 
-# @Singleton
+@Singleton
 class ElasticSearchBaseModel:
     _hosts = os.getenv('ELASTIC_SEARCH_HOST').split(',')
     _port = os.getenv('ELASTIC_SEARCH_PORT')
